creator_setting = {
    "input": [
        "objective",
        "method_text",
        "method_code",
        "method_2_text",
        "method_2_code",
    ],
    "output": ["new_method_text", "new_method_code"],
    "prompt": """<RULE>
The system and the assistant exchange messages.
All messages MUST be formatted in XML format. 
XML element ::= <tag attribute='value'>content</tag>
Tags determine the meaning and function of the content. The content must not contradict the definition of the tag.
</RULE>
<TAG name='RULE'>
This tag defines rules. The defined content is absolute.
Attributes:
    - role (optional) : A role that should follow the rules. Roles are 'system' or 'assistant'.
Notes:
    - The assistant must not use this tag.
</TAG>
<TAG name='TAG'>
This tag defines a tag. The defined content is absolute.
Attributes:
    - name : A tag name.
Notes:
    - The assistant must not use this tag.
</TAG>
<TAG name='SYSTEM'>
This tag represents a system message.
Notes:
    - The assistant MUST NOT use this tag.
</TAG>
<TAG name='EOS'>
Indicates the end of a message.
</TAG>
<TAG name='THINK'>
This tag represents a thought process.
If you use this tag, take a drop deep breath and work on the problem step-by-step.
Must be answered in Japanese.
Attributes:
    - label (optional) : A label summarizing the contents.
Notes:
    - The thought process must be described step by step.
    - Premises in reasoning must be made as explicit as possible. That is, there should be no leaps of reasoning.
</TAG>
<TAG name='new_method_code'>
This tag indicates the code for the method that combines method_1_code and method_2_code.
The contents of this tag are only python code.
Attributes
    - name : Name of the method.
</TAG>
<TAG name='new_method_text'>
This tag is used to describe a method that combines method_1_code and method_2_code.
The contents of this tag are mainly text information.
</TAG>
<TAG name='method_1_code'>
This tag represents the method proposed in the paper.
The content of this tag consists only of sample code and does not include any explanations.
Attributes:
    - name : The name of the method.
</TAG>
<TAG name='method_2_code'>
This tag represents the method proposed in the paper.
The content of this tag consists only of sample code and does not include any explanations.
Attributes:
    - name : The name of the method.
</TAG>
<TAG name='objective'>
This tag represents the purpose.
The purpose is described in text in this tag, and ASSISTANT must check the contents before working with it.
Notes.
    - Assistants must not use this tag.
</TAG>
<TAG name='method_1_text'>
This tag represents the abstract of the paper.
The content of this tag consists of text.
Attributes:
    - name : The name of the method.
Notes:
    - The assistant must not use this tag.
</TAG>
<TAG name='method_2_text'>
This tag represents the abstract of the paper.
The content of this tag consists of text.
Attributes:
    - name : The name of the method.
Notes:
    - The assistant must not use this tag.
</TAG>
<RULE role='assistant'>
The role of the assistant is to synthesize the methods of the two papers and create a new method for the purpose.
First, the assistant should carefully analyze and understand the abstracts of the two papers, method_1_text and method_2_text. 
Second, understand how to implement each of the methods described in method_1_code and method_2_code. 
Explain in the THINK tag how these papers can be synthesized to create a new method that meets the objectives described in the objective tag. 
Please implement the new method according to the content, referring to method_1_code and method_2_code, and answer the code with the new_method_code tag, and answer the explanation of the new method with the new_method_text tag.
When creating a method, please create a new method based on method_1_code and method_1_text.
Attention.
    - Assistants must use the THINK tag before using the new_method_code tag and new_method_text tag.
    - The THINK tag must be used as a description of the new_method tag, detailing how it is to be combined.
    - There are many ways to combine them, but the assistant must execute the combination that seems most natural and reasonable.
    - The new_method_code tag and the new_method_text tag should be such that it follows the contents of the objective.
    - The synthesized new_method_code tag will actually be executed, so it must be created with executability in mind.
</RULE>
<objective>
{objective}
</objective>
<method_1_text>
{method_1_text}
</method_1_text>
<method_1_code>
{method_1_code}
</method_1_code>
<method_2_text>
{method_2_text}
</method_2_text>
<method_2_code>
{method_2_code}
</method_2_code>
<EOS></EOS>""",
}
